==> zzyj-laborservice-api-3.0.0-20250211.091307-73-sources.jar: com/ejianc/business/laborlaw/vo/CaseRegisterVO.java <==
package com.ejianc.business.laborlaw.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.laborlaw.vo.CaseRegisterContractVO;
import com.ejianc.business.laborlaw.vo.CaseRegisterContractVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 劳务公司-诉讼案件登记
 * 
 * @author generator
 * 
 */
public class CaseRegisterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String contractId; // 收入合同id
    private String contractName; // 收入合同名称
    private String contractCode; // 合同编号
    private String contractType; // 合同类型
    private String projectManagerDeptId; // 项目管理部id
    private String projectManagerDept; // 项目管理部
    private String supplierId; // 乙方id
    private String supplier; // 乙方
    private String supplierSignerId; // 乙方签订人id
    private String supplierSignerName; // 乙方签订人
    private String plaintiff; // 原告
    private String defendant; // 被告
    private BigDecimal caseMny; // 诉讼金额
    private String caseType; // 案件类别
    private String disputeTypeName; // 纠纷类型名称
    private String caseStateName; // 案件状态
    private String caseReason; // 诉讼原因
    private String firstPartyId; // 甲方id
    private String firstPartyName; // 甲方
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String disputeType; // 纠纷类型
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date serviceDate; // 业务日期
    private String caseCode; // 案号
    private String selfCode; // 归档编号

    private List<CaseRegisterContractVO> caseRegisterContractList = new ArrayList<>(); // 劳务公司-诉讼案件登记-合同详情
    private List<CaseRegisterPersonVO> caseRegisterPersonList = new ArrayList<>(); // 劳务公司-诉讼案件登记-当事人

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    public String getProjectManagerDeptId() {
        return projectManagerDeptId;
    }

    public void setProjectManagerDeptId(String projectManagerDeptId) {
        this.projectManagerDeptId = projectManagerDeptId;
    }
    public String getProjectManagerDept() {
        return projectManagerDept;
    }

    public void setProjectManagerDept(String projectManagerDept) {
        this.projectManagerDept = projectManagerDept;
    }
    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplier() {
        return supplier;
    }

    public void setSupplier(String supplier) {
        this.supplier = supplier;
    }
    public String getSupplierSignerId() {
        return supplierSignerId;
    }

    public void setSupplierSignerId(String supplierSignerId) {
        this.supplierSignerId = supplierSignerId;
    }
    public String getSupplierSignerName() {
        return supplierSignerName;
    }

    public void setSupplierSignerName(String supplierSignerName) {
        this.supplierSignerName = supplierSignerName;
    }
    public String getPlaintiff() {
        return plaintiff;
    }

    public void setPlaintiff(String plaintiff) {
        this.plaintiff = plaintiff;
    }
    public String getDefendant() {
        return defendant;
    }

    public void setDefendant(String defendant) {
        this.defendant = defendant;
    }
    public BigDecimal getCaseMny() {
        return caseMny;
    }

    public void setCaseMny(BigDecimal caseMny) {
        this.caseMny = caseMny;
    }
    public String getCaseType() {
        return caseType;
    }

    public void setCaseType(String caseType) {
        this.caseType = caseType;
    }
    public String getDisputeTypeName() {
        return disputeTypeName;
    }

    public void setDisputeTypeName(String disputeTypeName) {
        this.disputeTypeName = disputeTypeName;
    }
    public String getCaseStateName() {
        return caseStateName;
    }

    public void setCaseStateName(String caseStateName) {
        this.caseStateName = caseStateName;
    }
    public String getCaseReason() {
        return caseReason;
    }

    public void setCaseReason(String caseReason) {
        this.caseReason = caseReason;
    }
    public String getFirstPartyId() {
        return firstPartyId;
    }

    public void setFirstPartyId(String firstPartyId) {
        this.firstPartyId = firstPartyId;
    }
    public String getFirstPartyName() {
        return firstPartyName;
    }

    public void setFirstPartyName(String firstPartyName) {
        this.firstPartyName = firstPartyName;
    }
    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getDisputeType() {
        return disputeType;
    }

    public void setDisputeType(String disputeType) {
        this.disputeType = disputeType;
    }
    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }
    public String getCaseCode() {
        return caseCode;
    }

    public void setCaseCode(String caseCode) {
        this.caseCode = caseCode;
    }
    public String getSelfCode() {
        return selfCode;
    }

    public void setSelfCode(String selfCode) {
        this.selfCode = selfCode;
    }

    public List<CaseRegisterContractVO> getCaseRegisterContractList() {
        return caseRegisterContractList;
    }

    public void setCaseRegisterContractList(List<CaseRegisterContractVO> caseRegisterContractList) {
        this.caseRegisterContractList = caseRegisterContractList;
    }

    public List<CaseRegisterPersonVO> getCaseRegisterPersonList() {
        return caseRegisterPersonList;
    }

    public void setCaseRegisterPersonList(List<CaseRegisterPersonVO> caseRegisterPersonList) {
        this.caseRegisterPersonList = caseRegisterPersonList;
    }
}

==> zzyj-laborservice-api-3.0.0-20250424.002759-90-sources.jar: com/ejianc/business/laborlaw/vo/CaseRegisterVO.java <==
package com.ejianc.business.laborlaw.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.laborlaw.vo.CaseRegisterContractVO;
import com.ejianc.business.laborlaw.vo.CaseRegisterContractVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 劳务公司-诉讼案件登记
 * 
 * @author generator
 * 
 */
public class CaseRegisterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String contractId; // 收入合同id
    private String contractName; // 收入合同名称
    private String contractCode; // 合同编号
    private String contractType; // 合同类型
    private String projectManagerDeptId; // 项目管理部id
    private String projectManagerDept; // 项目管理部
    private String supplierId; // 乙方id
    private String supplier; // 乙方
    private String supplierSignerId; // 乙方签订人id
    private String supplierSignerName; // 乙方签订人
    private String plaintiff; // 原告
    private String defendant; // 被告
    private BigDecimal caseMny; // 诉讼金额
    private String caseType; // 案件类别
    private String disputeTypeName; // 纠纷类型名称
    private String caseStateName; // 案件状态
    private String caseReason; // 诉讼原因
    private String firstPartyId; // 甲方id
    private String firstPartyName; // 甲方
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String disputeType; // 纠纷类型
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date serviceDate; // 业务日期
    private String caseCode; // 案号
    private String selfCode; // 归档编号

    private List<CaseRegisterContractVO> caseRegisterContractList = new ArrayList<>(); // 劳务公司-诉讼案件登记-合同详情
    private List<CaseRegisterPersonVO> caseRegisterPersonList = new ArrayList<>(); // 劳务公司-诉讼案件登记-当事人
    private List<InfoRegisterVO> infoRegisterList = new ArrayList<>(); // 案件审理信息表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    public String getProjectManagerDeptId() {
        return projectManagerDeptId;
    }

    public void setProjectManagerDeptId(String projectManagerDeptId) {
        this.projectManagerDeptId = projectManagerDeptId;
    }
    public String getProjectManagerDept() {
        return projectManagerDept;
    }

    public void setProjectManagerDept(String projectManagerDept) {
        this.projectManagerDept = projectManagerDept;
    }
    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplier() {
        return supplier;
    }

    public void setSupplier(String supplier) {
        this.supplier = supplier;
    }
    public String getSupplierSignerId() {
        return supplierSignerId;
    }

    public void setSupplierSignerId(String supplierSignerId) {
        this.supplierSignerId = supplierSignerId;
    }
    public String getSupplierSignerName() {
        return supplierSignerName;
    }

    public void setSupplierSignerName(String supplierSignerName) {
        this.supplierSignerName = supplierSignerName;
    }
    public String getPlaintiff() {
        return plaintiff;
    }

    public void setPlaintiff(String plaintiff) {
        this.plaintiff = plaintiff;
    }
    public String getDefendant() {
        return defendant;
    }

    public void setDefendant(String defendant) {
        this.defendant = defendant;
    }
    public BigDecimal getCaseMny() {
        return caseMny;
    }

    public void setCaseMny(BigDecimal caseMny) {
        this.caseMny = caseMny;
    }
    public String getCaseType() {
        return caseType;
    }

    public void setCaseType(String caseType) {
        this.caseType = caseType;
    }
    public String getDisputeTypeName() {
        return disputeTypeName;
    }

    public void setDisputeTypeName(String disputeTypeName) {
        this.disputeTypeName = disputeTypeName;
    }
    public String getCaseStateName() {
        return caseStateName;
    }

    public void setCaseStateName(String caseStateName) {
        this.caseStateName = caseStateName;
    }
    public String getCaseReason() {
        return caseReason;
    }

    public void setCaseReason(String caseReason) {
        this.caseReason = caseReason;
    }
    public String getFirstPartyId() {
        return firstPartyId;
    }

    public void setFirstPartyId(String firstPartyId) {
        this.firstPartyId = firstPartyId;
    }
    public String getFirstPartyName() {
        return firstPartyName;
    }

    public void setFirstPartyName(String firstPartyName) {
        this.firstPartyName = firstPartyName;
    }
    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getDisputeType() {
        return disputeType;
    }

    public void setDisputeType(String disputeType) {
        this.disputeType = disputeType;
    }
    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }
    public String getCaseCode() {
        return caseCode;
    }

    public void setCaseCode(String caseCode) {
        this.caseCode = caseCode;
    }
    public String getSelfCode() {
        return selfCode;
    }

    public void setSelfCode(String selfCode) {
        this.selfCode = selfCode;
    }

    public List<CaseRegisterContractVO> getCaseRegisterContractList() {
        return caseRegisterContractList;
    }

    public void setCaseRegisterContractList(List<CaseRegisterContractVO> caseRegisterContractList) {
        this.caseRegisterContractList = caseRegisterContractList;
    }

    public List<CaseRegisterPersonVO> getCaseRegisterPersonList() {
        return caseRegisterPersonList;
    }

    public void setCaseRegisterPersonList(List<CaseRegisterPersonVO> caseRegisterPersonList) {
        this.caseRegisterPersonList = caseRegisterPersonList;
    }

    public List<InfoRegisterVO> getInfoRegisterList() {
        return infoRegisterList;
    }

    public void setInfoRegisterList(List<InfoRegisterVO> infoRegisterList) {
        this.infoRegisterList = infoRegisterList;
    }
}
